@@ -115,7 +115,11 @@ RSpec.describe Zstd::StreamingCompress do
           stream << "abc" << "def"
           res = stream.finish
         }
-        expect(Zstd.decompress(r.take)).to eq('abcdef')
+        # Ractor#take was replaced at Ruby 3.5.
+        # https://bugs.ruby-lang.org/issues/21262
+        result = r.respond_to?(:take) ? r.take : r.value
+
+        expect(Zstd.decompress(result)).to eq('abcdef')
       end
     end
   end
